@@ -29,29 +29,30 @@ class BaseAPIView(APIView):
         return Response(serializer.data, status=status)
 
 
+
 class StandardAPIView(BaseAPIView):
-    def paginate_data(self, data, request, serializer_class=None, context=None, **kwargs):
-        # Create a paginator instance
-        paginator = self.pagination_class(**kwargs)
+    pagination_class = CustomPagination
 
-        # Paginate the data object and return the paginated response
-        paginated_data = paginator.paginate_data(data, request)
-        if serializer_class:
-            serializer = serializer_class(paginated_data, many=True, context=context)
-            paginated_data = serializer.data
-
-        # Include the count, next, and previous fields in the response
-        response = {
+    def send_paginated_response(self, data, status=status.HTTP_200_OK, next_url=None, previous_url=None, count=None):
+        serializer = APIResponseSerializer({
             'success': True,
-            'status': status.HTTP_200_OK,
-            'count': paginator.count,
-            'next': paginator.get_next_link(),
-            'previous': paginator.get_previous_link(),
-            'data': paginated_data,
-        }
+            'status': status,
+            'next': next_url,
+            'previous': previous_url,
+            'count': count,
+            'data': data
+        })
+        return Response(serializer.data, status=status)
 
-        # Return a Response object
-        return Response(APIResponseSerializer(response, context=context).data)
+    def paginate_data(self, data, request):
+        paginator = self.pagination_class()
+        paginated_data = paginator.paginate_data(data, request)
+        return self.send_paginated_response(
+            data=paginated_data.data,
+            next_url=paginated_data.get('next'),
+            previous_url=paginated_data.get('previous'),
+            count=paginated_data.count
+        )
 
 
 # ============= Demo Views ============= #
@@ -80,8 +81,8 @@ class HelloWorldViewFakeData(BaseAPIView):
         return self.send_response(self.fake_data)
 
 
-class HelloWorldPaginatedView(StandardAPIView):
-    def get(self, request, format=None):
+class MyPaginatedView(StandardAPIView):
+    def get(self, request):
         data = [
             {'id': 1, 'content': 'Hello'},
             {'id': 2, 'content': 'World'},
@@ -91,10 +92,24 @@ class HelloWorldPaginatedView(StandardAPIView):
             {'id': 6, 'content': 'Paginated'},
             {'id': 7, 'content': 'Response'},
         ]
-        if data:
-            return self.paginate_data(data, request, page_size=3, max_page_size=5)
-        else:
-            return self.send_error('No data found')
+        # data = get_data()  # Replace this with your own data
+        return self.paginate_data(data, request)
+
+# class HelloWorldPaginatedView(StandardAPIView):
+#     def get(self, request, format=None):
+#         data = [
+#             {'id': 1, 'content': 'Hello'},
+#             {'id': 2, 'content': 'World'},
+#             {'id': 3, 'content': 'This'},
+#             {'id': 4, 'content': 'Is'},
+#             {'id': 5, 'content': 'A'},
+#             {'id': 6, 'content': 'Paginated'},
+#             {'id': 7, 'content': 'Response'},
+#         ]
+#         if data:
+#             return self.paginate_data(data, request, page_size=3, max_page_size=5)
+#         else:
+#             return self.send_error('No data found')
 
 
 # class HelloWorldObjectPaginatedView(StandardAPIView):
